@@ -1,13 +1,15 @@
 # source: http://docs.gunicorn.org/en/stable/custom.html
 import multiprocessing
 import os
+from typing import Dict
 
 import gunicorn.app.base
+from flask import Flask
 from flask_migrate import upgrade
 from rdltr import create_app
 
 
-def number_of_workers():
+def number_of_workers() -> int:
     return (multiprocessing.cpu_count() * 2) + 1
 
 
@@ -21,12 +23,12 @@ app = create_app()
 
 
 class StandaloneApplication(gunicorn.app.base.BaseApplication):
-    def __init__(self, current_app, options=None):
+    def __init__(self, current_app: Flask, options: Dict = None) -> None:
         self.options = options or {}
         self.application = current_app
         super().__init__()
 
-    def load_config(self):
+    def load_config(self) -> None:
         config = {
             key: value
             for key, value in self.options.items()
@@ -35,16 +37,16 @@ class StandaloneApplication(gunicorn.app.base.BaseApplication):
         for key, value in config.items():
             self.cfg.set(key.lower(), value)
 
-    def load(self):
+    def load(self) -> Flask:
         return self.application
 
 
-def upgrade_db():
+def upgrade_db() -> None:
     with app.app_context():
         upgrade(directory=BASEDIR + '/migrations')
 
 
-def main():
+def main() -> None:
     options = {'bind': f"{HOST}:{PORT}", 'workers': WORKERS}
     StandaloneApplication(app, options).run()
 
