@@ -1,4 +1,7 @@
-from flask import Blueprint, current_app, jsonify, request
+from typing import Dict, Tuple
+
+from flask import Blueprint, current_app, request
+from flask_sqlalchemy import SQLAlchemy
 from sqlalchemy import exc, or_
 
 from .. import app_log, bcrypt, db
@@ -9,7 +12,7 @@ from .utils import authenticate, passwords_controls, register_controls
 auth_blueprint = Blueprint('auth', __name__)
 
 
-def handle_error(e, db):
+def handle_error(e: Exception, db: SQLAlchemy) -> Tuple[Dict, int]:
     db.session.rollback()
     app_log.error(e)
 
@@ -17,17 +20,17 @@ def handle_error(e, db):
         'status': 'error',
         'message': 'Error. Please try again or contact the administrator.',
     }
-    return jsonify(response_object), 500
+    return response_object, 500
 
 
 @auth_blueprint.route('/auth/register', methods=['POST'])
-def register_user():
+def register_user() -> Tuple[Dict, int]:
     if not current_app.config.get('REGISTRATION_ALLOWED'):
-        response_object = {
+        response_object: Dict = {
             'status': 'error',
             'message': 'Error. Registration is disabled.',
         }
-        return jsonify(response_object), 403
+        return response_object, 403
 
     # get post data
     post_data = request.get_json()
@@ -39,7 +42,7 @@ def register_user():
         or post_data.get('password_conf') is None
     ):
         response_object = {'status': 'error', 'message': 'Invalid payload.'}
-        return jsonify(response_object), 400
+        return response_object, 400
     username = post_data.get('username')
     email = post_data.get('email')
     password = post_data.get('password')
@@ -54,10 +57,10 @@ def register_user():
             'status': 'error',
             'message': 'Error. Please try again or contact the administrator.',
         }
-        return jsonify(response_object), 500
+        return response_object, 500
     if ret != '':
         response_object = {'status': 'error', 'message': 'Errors: ' + ret}
-        return jsonify(response_object), 400
+        return response_object, 400
 
     try:
         # check for existing user
@@ -83,25 +86,25 @@ def register_user():
                 'auth_token': auth_token,
                 'user': new_user.serialize(),
             }
-            return jsonify(response_object), 201
+            return response_object, 201
         else:
             response_object = {
                 'status': 'error',
                 'message': 'Sorry. That user already exists.',
             }
-            return jsonify(response_object), 400
+            return response_object, 400
     # handler errors
     except (exc.IntegrityError, exc.OperationalError, ValueError) as e:
         return handle_error(e, db)
 
 
 @auth_blueprint.route('/auth/login', methods=['POST'])
-def login_user():
+def login_user() -> Tuple[Dict, int]:
     # get post data
     post_data = request.get_json()
     if not post_data:
         response_object = {'status': 'error', 'message': 'Invalid payload.'}
-        return jsonify(response_object), 400
+        return response_object, 400
     email = post_data.get('email')
     password = post_data.get('password')
     try:
@@ -116,13 +119,13 @@ def login_user():
                 'auth_token': auth_token,
                 'user': user.serialize(),
             }
-            return jsonify(response_object), 200
+            return response_object, 200
         else:
             response_object = {
                 'status': 'error',
                 'message': 'Invalid credentials.',
             }
-            return jsonify(response_object), 400
+            return response_object, 400
     # handler errors
     except (exc.IntegrityError, exc.OperationalError, ValueError) as e:
         return handle_error(e, db)
@@ -130,26 +133,26 @@ def login_user():
 
 @auth_blueprint.route('/auth/logout', methods=['GET'])
 @authenticate
-def logout_user(user_id):
+def logout_user(user_id: int) -> Tuple[Dict, int]:
     # all checks are made by @authenticate
     response_object = {
         'status': 'success',
         'message': 'Successfully logged out.',
     }
-    return jsonify(response_object), 200
+    return response_object, 200
 
 
 @auth_blueprint.route('/auth/profile', methods=['GET'])
 @authenticate
-def get_user_status(user_id):
+def get_user_status(user_id: int) -> Tuple[Dict, int]:
     user = User.query.filter_by(id=user_id).first()
     response_object = {'status': 'success', 'user': user.serialize()}
-    return jsonify(response_object), 200
+    return response_object, 200
 
 
 @auth_blueprint.route('/auth/profile/edit', methods=['POST'])
 @authenticate
-def update_password(user_id):
+def update_password(user_id: int) -> Tuple[Dict, int]:
     # get post data
     post_data = request.get_json()
     if (
@@ -159,7 +162,7 @@ def update_password(user_id):
         or post_data.get('new_password_conf') is None
     ):
         response_object = {'status': 'error', 'message': 'Invalid payload.'}
-        return jsonify(response_object), 400
+        return response_object, 400
 
     user = User.query.filter_by(id=user_id).first()
 
@@ -169,7 +172,7 @@ def update_password(user_id):
             'status': 'error',
             'message': 'Invalid credentials.',
         }
-        return jsonify(response_object), 400
+        return response_object, 400
 
     password = post_data.get('new_password')
     password_conf = post_data.get('new_password_conf')
@@ -177,7 +180,7 @@ def update_password(user_id):
         ret = passwords_controls(password, password_conf)
         if ret != '':
             response_object = {'status': 'error', 'message': 'Errors: ' + ret}
-            return jsonify(response_object), 400
+            return response_object, 400
 
         user.password = bcrypt.generate_password_hash(
             password, current_app.config.get('BCRYPT_LOG_ROUNDS')
@@ -185,7 +188,7 @@ def update_password(user_id):
         db.session.commit()
 
         response_object = {'status': 'success', 'user': user.serialize()}
-        return jsonify(response_object), 200
+        return response_object, 200
     except (
         exc.IntegrityError,
         exc.OperationalError,
